import Editor, { EditorOptions } from "@toast-ui/editor";
export interface RichTextEditorPlugin<TOptions = any> {
    plugin: (staticEditor: typeof Editor, options?: TOptions) => (editor: Editor) => void;
    options?: TOptions;
}
declare const defaultToolbarItems: readonly ["heading", "bold", "italic", "strike", "divider", "ul", "ol", "task", "indent", "outdent", "hr", "qoute", "table", "image", "link", "code", "codeBlock"];
declare type DefaultToolbarItem = typeof defaultToolbarItems[number];
export interface IRichTextEditorOptions {
    /**
     * Selector or HTML element for the text area you want to initialize
     */
    textArea: string | HTMLElement;
    /**
     * Optional: The height of rich text editor. If not provided, the height will be auto.
     */
    height?: string;
    /**
     * Optional: The min height of rich text editor. If not provided, the height will be 550px.
     */
    minHeight?: string;
    /**
     * Optional: The language of the editor. If not provided, the default language will be danish.
     */
    languageSettings?: ILanguageSettings;
    /**
     * Optional: Which toolbar items to show. If not provided, the default toolbar items will be shown.
     */
    toolbarItems?: IToolbarItems;
    /**
     * Optional: The ability to switch editor mode ("wysiwyg" and "markdown"). If not provided, the button to switch between modes will not be shown.
     */
    showModeSwitch?: boolean;
    /**
     * Optional: The editors mode. If not provided, the default editor mode will be "wysiwyg".
     */
    editorMode?: "wysiwyg" | "markdown";
    /**
     * Optional: Customplugin for the editor if needed.
     */
    customPlugins?: RichTextEditorPlugin[];
    /**
     * Optional: Override additional settings. Does not override settings defined in IRichTextEditorOptions.
     */
    additionalRichTextEditorSettings?: EditorOptions;
    /**
     * Optional: Prevent enter event and shift+enter event in WYSIWYG editor .
     */
    preventNewLine?: boolean;
    /**
     * Optional: On change callback.
     */
    onEditorChanged?: () => void;
}
export interface IToolbarItems {
    /**
     * Optional: Override with custom toolbar, supplying the buttons and their order. Takes a list of strings which can be the buttons included in the rich text editor, or buttons of any provided plugins. If not provided default settings will apply.
     * The included button options are: "heading", "bold", "italic", "strike", "divider", "ul", "ol", "task", "indent", "outdent", "hr", "qoute", "table", "image", "link", "code", "codeBlock".
     */
    customToolbar?: (DefaultToolbarItem | string)[];
    /**
     * Optional: Bold text style. If not provided, the style button will be available.
     */
    showBold?: boolean;
    /**
     * Optional: Provide headings for the module.  If not provided, the style button will be available.
     */
    showHeadings?: boolean;
    /**
     * Optional: Italic text style. If not provided, the style button will be available.
     */
    showItalic?: boolean;
    /**
     * Optional: Strike text style. If not provided, the style button will be available.
     */
    showStrike?: boolean;
    /**
     * Optional: A button for creating a horizontal line. If not provided, button will not be available.
     */
    showHr?: boolean;
    /**
     * Optional: A button for creating a blockqoute. If not provided, the button will not be available.
     */
    showBlockQuote?: boolean;
    /**
     * Optional: Button for creating unordered lists. If not provided, the list button will be available.
     */
    showULListOption?: boolean;
    /**
     * Optional: Button for creating ordered lists. If not provided, the list button will be available.
     */
    showOLListOption?: boolean;
    /**
     * Optional: Button for creating a task lists. If not provided, the list button will not be available.
     */
    showTaskListOption?: boolean;
    /**
     * Optional: Button for indenting a list. If not provided, the list button will be available.
     */
    showIndentListOption?: boolean;
    /**
     * Optional: Button for outdenting a lists. If not provided, the list button will be available.
     */
    showOutdentListOption?: boolean;
    /**
     * Optional: Button for creating a table. If not provided, the table button will not be available.
     */
    showTable?: boolean;
    /**
     * Optional: Button for creating a image. If not provided, the image button will not be available.
     */
    showImage?: boolean;
    /**
     * Optional: Button for creating a link. If not provided, the link button will not be available.
     */
    showLink?: boolean;
    /**
     * Optional: Buttons for creating a codeblock or inline code. If not provided, the buttons will not be available.
     */
    showCode?: boolean;
}
export interface ILanguageSettings {
    /**
     * The editors language. Use "custom" and the language dictionary to provide your own translations.
     */
    language: "en-GB" | "da-DK" | "custom";
    /**
     * Optional: Must be provided when using the "Custom" option for language. Every property must be translated if provided.
     */
    languageDictionary?: {
        "Markdown": string;
        "WYSIWYG": string;
        "Write": string;
        "Preview": string;
        "Headings": string;
        "Paragraph": string;
        "Bold": string;
        "Italic": string;
        "Strike": string;
        "Code": string;
        "Line": string;
        "Blockquote": string;
        "Unordered list": string;
        "Ordered list": string;
        "Task": string;
        "Indent": string;
        "Outdent": string;
        "Insert link": string;
        "Insert CodeBlock": string;
        "Insert table": string;
        "Insert image": string;
        "Heading": string;
        "Image URL": string;
        "Select image file": string;
        "Description": string;
        "OK": string;
        "More": string;
        "Cancel": string;
        "File": string;
        "URL": string;
        "Link text": string;
        "Add row": string;
        "Add col": string;
        "Remove row": string;
        "Remove col": string;
        "Align left": string;
        "Align center": string;
        "Align right": string;
        "Remove table": string;
        "Would you like to paste as table?": string;
        "Text color": string;
        "Auto scroll enabled": string;
        "Auto scroll disabled": string;
        "Choose language": string;
    };
}
export declare class RichTextEditorModule {
    editor: Editor;
    constructor(options: IRichTextEditorOptions);
    getHtml(): string;
    getMarkdown(): string;
    private initModule;
    private generateDefaultSettings;
    private setLanguage;
    private generateToolbarFromOptions;
    private insertDividerinToolbarIfLastItemIsNotDivider;
    private isToolbarItemCustom;
}
export {};
